Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/model/model.h')
-rw-r--r--src/model/model.h33
1 files changed, 11 insertions, 22 deletions
diff --git a/src/model/model.h b/src/model/model.h
index 4d72793..3e6bd2d 100644
--- a/src/model/model.h
+++ b/src/model/model.h
@@ -43,8 +43,8 @@ public:
/// type definition for a list of model flare tags
typedef std::list<Flare *> Flares;
- /// type definition for a list of model dock tags
- typedef std::list<Dock *> Docks;
+ /// type definition for a list of model slot tags
+ typedef std::list<Slot *> Slots;
/// type definition for a list of model particle system tags
typedef std::list<Particles *> ParticleSystems;
@@ -52,9 +52,6 @@ public:
/// type definition for a list of model sound tags
typedef std::list<Sound *> Sounds;
- /// type definition for a list of model weapon tags
- typedef std::list<Weapon *> Weapons;
-
/// type definition for a list of FragmentGroups
typedef std::list<FragmentGroup *> Groups;
@@ -92,9 +89,9 @@ public:
return model_lights;
}
- /// list of model dock tags
- inline Docks & docks() {
- return model_docks;
+ /// list of model slot tags
+ inline Slots & slots() {
+ return model_slots;
}
/// list of model flare tags
@@ -107,11 +104,6 @@ public:
return model_sounds;
}
- /// list of model weapon tags
- inline Weapons & weapons() {
- return model_weapons;
- }
-
/// list of model particle system tags
inline ParticleSystems & particles() {
return model_particles;
@@ -150,12 +142,9 @@ public:
/// add a flare tag to the model
void add_flare(Flare *flare);
- /// add a docking location tag to the model
- void add_dock(Dock *dock);
+ /// add a slot tag to the model
+ void add_slot(Slot *slot);
- /// add a weapon slot tag to the model
- void add_weapon(Weapon *weapon);
-
/// add a sound tag to the model
void add_sound(Sound *sound);
@@ -220,16 +209,16 @@ private:
void sort();
std::string model_name;
- Docks model_docks;
+ Slots model_slots;
Flares model_flares;
Sounds model_sounds;
Lights model_lights;
ParticleSystems model_particles;
- Weapons model_weapons;
Groups model_groups;
- float model_radius;
- static Registry model_registry;
+ float model_radius;
CollisionModel *model_collisionmodel;
+
+ static Registry model_registry;
};
}